#define MSG_TIMEOUT "Zeitberschreitung"
#define MSG_CAPABILITIES "Konnte Berechtigungen (CAPABILITES) nicht wechseln."
#define MSG_CLIENT_CLOSED_CNX "Die Gegenstelle hat die Verbindung geschlossen."
#define MSG_CLIENT_READ_ERR "Lesefehler von Gegenstelle."
#define MSG_CANT_OPEN_CNX "Kann die Verbindung nicht erffnen."
#define MSG_CANT_CREATE_DATA_SOCKET "Kann die Datenverbindung nicht aufbauen."
#define MSG_DEBUG_CLIENT_IS "Addresse der Gegenstelle: "
#define MSG_SYNTAX_ERROR_IP "Syntaxfehler in IP-Addresse."
#define MSG_PORT_SUCCESSFUL "PORT-Kommando erfolgreich."
#define MSG_ONLY_IPV4V6 "Es werden nur IPv4 und IPv6 untersttzt (1,2)."
#define MSG_ONLY_IPV4 "Es wird nur IPv4 untersttzt (1)."
#define MSG_TIMEOUT_PARSER "Zeitberschreitung - Versuchen Sie, das nchste mal etwas schneller zu schreiben."
#define MSG_LINE_TOO_LONG "Die Zeile ist zu lang."
#define MSG_LOG_OVERFLOW "Die Gegenstelle hat versucht, den Kommandozeilenbuffer zu berfluten."
#define MSG_GOODBYE "Tsch. Transfer: upload %llu und download %llu kbytes."
#define MSG_DEBUG_COMMAND "Befehl"
#define MSG_IS_YOUR_CURRENT_LOCATION "ist das aktuelle Verzeichnis."
#define MSG_NOT_LOGGED_IN "Sie sind nicht angemeldet."
#define MSG_AUTH_UNIMPLEMENTED "Sicherheitserweiterung nicht implementiert."
#define MSG_NO_FILE_NAME "Kein Dateiname."
#define MSG_NO_DIRECTORY_NAME "Kein Verzeichnisname."
#define MSG_NO_RESTART_POINT "Keine Neustart-Position."
#define MSG_ABOR_SUCCESS "Wenn Sie das hier lesen, wurde offenbar erfolgreich abgebrochen."
#define MSG_MISSING_ARG "Fehlendes Argument."
#define MSG_GARBAGE_FOUND "Mll nach dem Wert gefunden."
#define MSG_VALUE_TOO_LARGE "Wert ist zu gro."
#define MSG_IDLE_TIME "Leerlaufzeit auf %lu Sekunden gesetzt."
#define MSG_SITE_HELP "Die folgenden SITE-Befehle werden untersttzt"
#define MSG_BAD_CHMOD "Ungltige Rechte."
#define MSG_UNKNOWN_EXTENSION "ist eine unbekannte Erweiterung."
#define MSG_XDBG_OK "XDBG-Befehl erfolgreich, debug-level ist jetzt %d."
#define MSG_UNKNOWN_COMMAND "Unbekannter Befehl."
#define MSG_TIMEOUT_NOOP "Zeitberschreitung (keine Aktion seit %lu Sekunden)."
#define MSG_TIMEOUT_DATA "Zeitberschreitung (keine neuen Daten seit %lu Sekunden)."
#define MSG_SLEEPING "Schnarch..."
#define MSG_ALREADY_LOGGED "Sie sind bereits angemeldet."
#define MSG_ANY_PASSWORD "Jedes Pawort wird akzeptiert."
#define MSG_ANONYMOUS_LOGGED "Anonymer Benutzer angemeldet."
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonymer Benutzer im virtuellen FTP eingeloggt."
#define MSG_USER_OK "Benutzer %s OK. Pawort erforderlich."
#define MSG_CANT_DO_TWICE "Wir knnen das nicht in der aktuellen Sitzung tun."
#define MSG_UNABLE_SECURE_ANON "Sicheres anonymes FTP konnte nicht bereitgestellt werden."
#define MSG_BANDWIDTH_RESTRICTED "Ihre Bandbreitenbenutzung ist limitiert."
#define MSG_NO_PASSWORD_NEEDED "Wozu ein Pawort, kleiner anonymer Feigling?"
#define MSG_NOTRUST "Kann ich Ihnen vertrauen?"
#define MSG_WHOAREYOU "Wer sind Sie ?"
#define MSG_AUTH_FAILED "Authentifizierung fehlgeschlagen, sorry."
#define MSG_AUTH_TOOMANY "Zu viele Authentifizierungsfehler."
#define MSG_NO_HOMEDIR "Home-Verzeichnis nicht erreichbar - Abbruch."
#define MSG_NO_HOMEDIR2 "%s existiert nicht oder ist nicht erreichbar."
#define MSG_START_SLASH "Starte in /."
#define MSG_USER_GROUP_ACCESS "Benutzer %s hat Gruppenzugang zu"
#define MSG_FXP_SUPPORT "Dieser Server untersttzt FXP."
#define MSG_RATIO "Sie mssen ein %u:%u (UL/DL) - Verhltnis akzeptieren."
#define MSG_CHROOT_FAILED "Konnte kein sicheres chroot()-Gefngnis einrichten."
#define MSG_CURRENT_DIR_IS "OK. Aktuelles Verzeichnis ist %s."
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktuelles, beschrnktes Verzeichnis ist %s."
#define MSG_IS_NOW_LOGGED_IN "%s ist jetzt eingeloggt."
#define MSG_CANT_CHANGE_DIR "Kann nicht ins Verzeichnis %s wechseln"
#define MSG_PATH_TOO_LONG "Pfad ist zu lang."
#define MSG_CANT_PASV "PASV ist nicht geeignet fr IPv6. Nehmen Sie EPSV."
#define MSG_CANT_PASSIVE "Kann keine passive Verbindung herstellen."
#define MSG_PORTS_BUSY "Alle reservierten TCP-ports sind belegt."
#define MSG_GETSOCKNAME_DATA "Kann den lokalen Daten-Socket nicht identifizieren."
#define MSG_GETPEERNAME "Kann den lokalen Socket nicht identifizieren."
#define MSG_INVALID_IP "Ungltige Adresse."
#define MSG_NO_EPSV "Bitte benutzen Sie einen IPv6-konformen Klienten mit EPSV-Untersttzung."
#define MSG_BAD_PORT "Ich verbinde nicht zu ports kleiner als 1024."
#define MSG_NO_FXP "Ich werde keine Verbindung mit %s herstellen (nur zu %s)."
#define MSG_FXP "FXP-Transfer: von %s to %s."
#define MSG_NO_DATA_CONN "Keine Datenverbindung."
#define MSG_ACCEPT_FAILED "Die Verbindung wird nicht akzeptiert."
#define MSG_ACCEPT_SUCCESS "Verbindung akzeptiert."
#define MSG_CNX_PORT_FAILED "Kann keine Datenverbindung zu Port %d aufbauen."
#define MSG_CNX_PORT "Verbinde mit Port %d."
#define MSG_ANON_CANT_MKD "Sorry, anonyme Benutzer drfen keine Verzeichnisse anlegen."
#define MSG_ANON_CANT_RMD "Sorry, anonyme Benutzer drfen keine Verzeichnisse lschen."
#define MSG_ANON_CANT_RENAME "Anonyme Benutzer drfen keine Dateien verschieben oder umbenennen."
#define MSG_ANON_CANT_CHANGE_PERMS "Anonyme Benutzer drfen die Rechte nicht vernderen."
#define MSG_GLOB_NO_MEMORY "Nicht genug Speicher beim Vervollstndigen von %s."
#define MSG_PROBABLY_DENIED "(Das bedeutet eventuell \"Erlaubnis verweigert\")."
#define MSG_GLOB_READ_ERROR "Lesefehler beim Vervollstndigen von %s."
#define MSG_GLOB_NO_MATCH "Kein Erfolg fr %s in %s."
#define MSG_CHMOD_FAILED "Konnte die Zugriffsrechte von %s nicht verndern."
#define MSG_CHMOD_SUCCESS "Zugriffsrechte von %s gendert."
#define MSG_CHMOD_TOTAL_FAILURE "Sorry, ich kann berhaupt keine Rechte ndern."
#define MSG_ANON_CANT_DELETE "Anonyme Benutzer drfen keine Dateien lschen."
#define MSG_ANON_CANT_OVERWRITE "Anonyme Benutzer drfen keine existierenden Dateien berschreiben."
#define MSG_DELE_FAILED "Konnte %s nicht lschen."
#define MSG_DELE_SUCCESS "%s gelscht."
#define MSG_DELE_TOTAL_FAILURE "Keine Datei gelscht."
#define MSG_LOAD_TOO_HIGH \
    "Zum Zeitpunkt der Verbindung war die Last %3.2f. Wir erlauben keinen Download\n" \
    "durch anonyme Benutzer wenn die Last so hoch ist. Uploads sind\n" \
    "immer erlaubt."
#define MSG_OPEN_FAILURE "Kann %s nicht ffnen"
#define MSG_OPEN_FAILURE2 "Kann diese Datei nicht ffnen."
#define MSG_STAT_FAILURE "Kann Dateigre nicht ermitteln."
#define MSG_STAT_FAILURE2 "Kann die Existenz der Datei nicht berprfen."
#define MSG_REST_TOO_LARGE_FOR_FILE "Neustart-Position %lld ist zu gro fr Dateigre %lld."
#define MSG_REST_RESET "Neustart-Position auf 0 zurckgesetzt."
#define MSG_NOT_REGULAR_FILE "Ich kann nur regulre Dateien empfangen."
#define MSG_NOT_MODERATED \
    "Diese Datei wurde von einem anonmyen Benutzer hochgeladen. Sie wurde noch\n" \
    "nicht durch die Administratoren zum Download freigegeben."
#define MSG_RATIO_DENIAL \
    "Sorry, aber das Upload/Download-Verhltnis ist %u:%u .\n" \
    "Bis jetzt haben Sie %llu Kb hochgeladen und %llu Kb heruntergeladen.\n" \
    "Bitte laden Sie mehr hoch und probieren Sie es spter noch einmal."
#define MSG_NO_MORE_TO_DOWNLOAD "Nichts mehr brig zum Herunterladen."
#define MSG_WINNER "Der Computer ist Ihr Freund. Trauen Sie ihrem Computer."
#define MSG_KBYTES_LEFT "noch %.1f kbytes."
#define MSG_ABORTED "Transfer abgebrochen."
#define MSG_DATA_WRITE_FAILED "Fehler whrend Schreibvorgang zur Datenverbindung."
#define MSG_DATA_READ_FAILED "Fehler whrend Lesevorgang von der Datenverbindung."
#define MSG_MMAP_FAILED "Kann die Datei nicht im Speicher halten."
#define MSG_WRITE_FAILED "Fehler beim Abspeichern als Datei."
#define MSG_TRANSFER_RATE_M "%.3f s (hier gemessen), %.2f Mbytes pro Sekunde."
#define MSG_TRANSFER_RATE_K "%.3f s (hier gemessen), %.2f Kbytes pro Sekunde."
#define MSG_TRANSFER_RATE_B "%.3f s (hier gemessen), %.2f bytes pro Sekunde."
#define MSG_SPACE_FREE_M "%.1f Mbytes freier Festplattenplatz."
#define MSG_SPACE_FREE_K "%f Kbytes freier Festplattenplatz."
#define MSG_DOWNLOADED "heruntergeladen."
#define MSG_REST_NOT_NUMERIC "REST bentigt einen numerischen Paramter."
#define MSG_REST_ASCII_STRICT "Antwort-Markierung mu im ASCII-Modus 0 sein."
#define MSG_REST_ASCII_WORKAROUND "Neustart bei %lld. Aber im ASCII-Modus."
#define MSG_REST_SUCCESS "Neustart bei %lld."
#define MSG_SANITY_DIRECTORY_FAILURE "Unzulssiger Verzeichnisname."
#define MSG_SANITY_FILE_FAILURE "Verbotener Dateiname: %s."
#define MSG_MKD_FAILURE "Kann Verzeichnis nicht erstellen."
#define MSG_MKD_SUCCESS "Das Verzeichnis wurde erfolgreich angelegt."
#define MSG_RMD_FAILURE "Kann Verzeichnis nicht entfernen."
#define MSG_RMD_SUCCESS "Das Verzeichnis wurde erfolgreich entfernt."
#define MSG_TIMESTAMP_FAILURE "Kann keinen Zeitstempel erzeugen."
#define MSG_MODE_ERROR "Nur ASCII- und Binrmodus werden untersttzt."
#define MSG_CREATE_FAILURE "Kann die Datei nicht erstellen."
#define MSG_ABRT_ONLY "ABRT ist das einzig gltige Kommando whrend des Hochladens."
#define MSG_UPLOAD_PARTIAL "teilweise hochgeladen."
#define MSG_REMOVED "entfernt."
#define MSG_UPLOADED "hochgeladen."
#define MSG_GMTIME_FAILURE "Konnte lokale Zeit nicht ermitteln."
#define MSG_TYPE_8BIT_FAILURE "Es werden nur 8-bit Bytes untersttzt."
#define MSG_TYPE_UNKNOWN "Unbekannter TYPE."
#define MSG_TYPE_SUCCESS "TYPE ist jetzt"
#define MSG_STRU_FAILURE "Es wird nur F(ile) untersttzt."
#define MSG_MODE_FAILURE "Bitte den S(tream)-Modus benutzen."
#define MSG_RENAME_ABORT "Breche vorheriges Umbenennen ab."
#define MSG_RENAME_RNFR_SUCCESS "RNFR akzeptiert - Datei existiert, bereit fr neuen Namen."
#define MSG_FILE_DOESNT_EXIST "Sorry, die Datei existiert nicht."
#define MSG_RENAME_ALREADY_THERE "Umbenennen fehlgeschlagen - Zieldatei existiert bereits."
#define MSG_RENAME_NORNFR "Keine Quelldatei zum Umbenennen angegeben (Brauche RNFR vor RNTO)."
#define MSG_RENAME_FAILURE "Fehler beim Umbenennen/Verschieben."
#define MSG_RENAME_SUCCESS "Datei erfolgreich umbenannt oder verschoben."
#define MSG_NO_SUPERSERVER "Bitte lassen Sie pure-ftpd von einem super-server (tcpserver, xinetd, ...) starten."
#define MSG_NO_FTP_ACCOUNT "Kann das 'ftp' - Nutzerkonto nicht finden."
#define MSG_CONF_ERR "Konfigurationsfehler."
#define MSG_NO_VIRTUAL_FILE "Datei fr virtuelle Benutzer fehlt."
#define MSG_ILLEGAL_THROTTLING "Ungltiger Wert fr die Bandbreitenbegrenzung."
#define MSG_ILLEGAL_TRUSTED_GID "Ungltige Gruppenid fr chroot."
#define MSG_ILLEGAL_USER_LIMIT "Ungltige Benutzergrenze."
#define MSG_ILLEGAL_FACILITY "Name der facility unbekannt."
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Ungltige LDAP-Konfigurationsdatei."
#define MSG_ILLEGAL_LOAD_LIMIT "Ungltige Lastgrenze."
#define MSG_ILLEGAL_PORTS_RANGE "Ungltiger Portbereich."
#define MSG_ILLEGAL_LS_LIMITS "Ungltige Beschrnkungen fr 'ls'."
#define MSG_ILLEGAL_FORCE_PASSIVE "Die erzwungene IP-Adresse fr passive Verbindungen ist ungltig."
#define MSG_ILLEGAL_RATIO "Ungltige Upload/Download - Beschrnkung."
#define MSG_ILLEGAL_UID_LIMIT "Ungltige uid-Beschrnkung."
#define MSG_ILLEGAL_OPTION "Unbekannte Laufzeitoption."
#define MSG_LDAP_MISSING_BASE "Fehlendes LDAP-BaseDN in der LDAP-Konfigurationsdatei."
#define MSG_LDAP_WRONG_PARMS "Falsche LDAP-Parameter."
#define MSG_NEW_CONNECTION "Neue Verbindung von %s."
#define MSG_WELCOME_TO "Herzlich willkommen auf"
#define MSG_MAX_USERS "%lu Benutzer (maximal) sind schon eingeloggt, sorry."
#define MSG_NB_USERS "Sie sind Benutzer %d von %d erlaubten."
#define MSG_WELCOME_TIME "Lokale Zeit: %02d:%02d. Serverport: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Nur anonymes FTP erlaubt."
#define MSG_RATIOS_EVERYONE "RATIOS SIND FR JEDEN AKTIVIERT:"
#define MSG_RATIOS_ANONYMOUS "ANONYME NUTZER UNTERLIEGEN EINER UPLOAD/DOWNLOAD-QUOTE:"
#define MSG_RATIOS_RULE "um %u Mb herunterzuladen, mssen %u Mb hochgeladen werden."
#define MSG_INFO_IDLE_M "Sie werden nach %lu Minuten Inaktivitt getrennt."
#define MSG_INFO_IDLE_S "Sie werden nach %lu Sekunden Inaktivitt getrennt."
#define MSG_CANT_READ_FILE "konnte [%s] nicht lesen."
#define MSG_LS_TRUNCATED "Anzeige auf %u Eintrge beschrnkt."
#define MSG_LS_SUCCESS "%u Eintrge gesamt."
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Authentifizierung fehlgeschlagen fr Benutzer [%s]."
#define MSG_ILLEGAL_UMASK "Ungltige umask."
#define MSG_STANDALONE_FAILED "Kann keinen autarken Server starten"
#define MSG_NO_ANONYMOUS_LOGIN "Dies ist ein privates System - Keine anonyme Anmeldung mglich."
#define MSG_ANONYMOUS_ANY_PASSWORD "jedes Pawort funktioniert."
#define MSG_MAX_USERS_IP "Zuviele Verbindungen (%lu) von dieser IP-Adresse."
#define MSG_ACTIVE_DISABLED "Aktives FTP ist auf diesem Server verboten."
#define MSG_TRANSFER_SUCCESSFUL "Datei erfolgreich bertragen."
#define MSG_NO_DISK_SPACE "Festplatte voll - bitte spter hochladen."
#define MSG_OUT_OF_MEMORY "Nicht genug Arbeitsspeicher."
#define MSG_ILLEGAL_TRUSTED_IP "Ungltige vertraute IP-Adresse."
#define MSG_NO_ASCII_RESUME "Wiederaufnahme im ASCII-Modus ist unsicher, bitte lschen Sie die Datei zuerst."
#define MSG_UNKNOWN_ALTLOG "Unbekanntes Format fr Logdatei."
#define MSG_ACCOUNT_DISABLED "Einloggen als [%s] nicht mglich: Konto deaktiviert."
#define MSG_SQL_WRONG_PARMS "Falsche SQL-Parameter."
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Ungltige SQL-Konfigurationsdatei."
#define MSG_SQL_MISSING_SERVER "Kein SQL-Server in Konfigurationsdatei angegeben."
#define MSG_SQL_DOWN "Der SQL-Server ist nicht erreichbar."
#define MSG_ILLEGAL_QUOTA "Quota ungltig."
#define MSG_QUOTA_FILES "%llu Dateien benutzt (%d%%) - erlaubt: %llu Dateien."
#define MSG_QUOTA_SIZE "%llu Kilobyte benutzt (%d%%) - erlaubt: %llu Kb."
#define MSG_QUOTA_EXCEEDED "Quota berschritten: [%s] wird nicht gespeichert."
#define MSG_AUTH_UNKNOWN "Unbekannte Authentifizierungsmethode."
#define MSG_PDB_BROKEN "Konnte indizierte puredb-Datei nicht lesen (oder altes Format gefunden) - Versuche pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s ist ein Alias fr %s."
#define MSG_ALIASES_UNKNOWN "Unbekannter Alias %s."
#define MSG_ALIASES_BROKEN_FILE "Beschdigte Aliasdatei"
#define MSG_ALIASES_LIST "Folgende Aliase stehen zur Verfgung:"
#define MSG_PERUSER_MAX "Mehr als %lu Verbindungen vom selben Benutzer sind nicht erlaubt"
#define MSG_IPV6_OK "Auf diesem Server sind auch IPv6-Verbindungen willkommen"
#define MSG_TLS_INFO "SSL/TLS: %s Verschlsselung mit %s, %d bit Schlssellnge"
#define MSG_TLS_WEAK "SSL/TLS: Verschlsselung zu schwach"
#define MSG_TLS_NEEDED "Sorry, unverschlsselte Sitzungen werden auf diesem Server nicht akzeptiert.\n" \
    "Bitte verbinden Sie sich mittels SSL/TLS-Verschlsselung"
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
